==> wallaroo-2023.2.1rc1.tar.gz: wallaroo-2023.2.1rc1/wallaroo/wallaroo_ml_ops_api_client/models/assays_list_response_200_item_baseline_type_1.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
  from ..models.assays_list_response_200_item_baseline_type_1_fixed import \
      AssaysListResponse200ItemBaselineType1Fixed





T = TypeVar("T", bound="AssaysListResponse200ItemBaselineType1")


@attr.s(auto_attribs=True)
class AssaysListResponse200ItemBaselineType1:
    """ 
        Attributes:
            fixed (AssaysListResponse200ItemBaselineType1Fixed):
     """

    fixed: 'AssaysListResponse200ItemBaselineType1Fixed'
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)


    def to_dict(self) -> Dict[str, Any]:
        fixed = self.fixed.to_dict()


        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "Fixed": fixed,
        })

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.assays_list_response_200_item_baseline_type_1_fixed import \
            AssaysListResponse200ItemBaselineType1Fixed
        d = src_dict.copy()
        fixed = AssaysListResponse200ItemBaselineType1Fixed.from_dict(d.pop("Fixed"))




        assays_list_response_200_item_baseline_type_1 = cls(
            fixed=fixed,
        )

        assays_list_response_200_item_baseline_type_1.additional_properties = d
        return assays_list_response_200_item_baseline_type_1

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> wallaroo-2023.3.0b0.tar.gz: wallaroo-2023.3.0b0/wallaroo/wallaroo_ml_ops_api_client/models/assays_list_response_200_item_baseline_type_1.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
  from ..models.assays_list_response_200_item_baseline_type_1_user_provided import \
      AssaysListResponse200ItemBaselineType1UserProvided





T = TypeVar("T", bound="AssaysListResponse200ItemBaselineType1")


@attr.s(auto_attribs=True)
class AssaysListResponse200ItemBaselineType1:
    """ 
        Attributes:
            user_provided (AssaysListResponse200ItemBaselineType1UserProvided):
     """

    user_provided: 'AssaysListResponse200ItemBaselineType1UserProvided'
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)


    def to_dict(self) -> Dict[str, Any]:
        user_provided = self.user_provided.to_dict()


        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "UserProvided": user_provided,
        })

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.assays_list_response_200_item_baseline_type_1_user_provided import \
            AssaysListResponse200ItemBaselineType1UserProvided
        d = src_dict.copy()
        user_provided = AssaysListResponse200ItemBaselineType1UserProvided.from_dict(d.pop("UserProvided"))




        assays_list_response_200_item_baseline_type_1 = cls(
            user_provided=user_provided,
        )

        assays_list_response_200_item_baseline_type_1.additional_properties = d
        return assays_list_response_200_item_baseline_type_1

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
